graph_endorsement = {"MAIN_TABLE": "EN_AVAL_INSTITUCION",
                     "CHECKPOINT": {"DB": "__INSTITULAC__", "KEYS": ["COD_AVAL_INSTITUCION"]},
                     "SCHEMA_VERSION": 0.1,
                     "GRAPH": [{"EN_AVAL_INSTITUCION": None}]}


graph_product = {"MAIN_TABLE": "EN_PRODUCTO",
                 "CHECKPOINT": {"DB": "__CVLAC__", "KEYS": ["COD_RH", "COD_PRODUCTO"]},
                 "SCHEMA_VERSION": 0.1,
                 "GRAPH": [{"EN_PRODUCTO": [
                     # autor registrante
                     {"KEYS": ["COD_RH"],
                      "DB":"__CVLAC__",
                      "TABLES":[{'EN_RECURSO_HUMANO': [
                                # municipio
                                 {"KEYS": ["COD_RH_MUN_NACIM/COD_RH_MUNICIPIO", "COD_MUN_NACIM/COD_MUNICIPIO"],
                                  "DB":"__CVLAC__",
                                  "TABLES":[{'EN_MUNICIPIO': [
                                      # departamento
                                      {"KEYS": ["SGL_PAIS", "SGL_DEPARTAMENTO"],
                                       "DB":"__CVLAC__",
                                       "TABLES":[{'EN_DEPARTAMENTO': [
                                           # pais
                                           {"KEYS": ["SGL_PAIS"],
                                            "DB":"__CVLAC__",
                                            "TABLES":[{'EN_PAIS': None}]},

                                       ]}]},
                                  ]}]},
                                 # level of studies
                                 {"KEYS": ["COD_NIVEL_FORMACION"],
                                  "DB":"__CVLAC__",
                                  "TABLES":[{'EN_NIVEL_FORMACION': None}]},
                                 ]},
                                ]},

                     # institucion registrante
                     {"KEYS": ["COD_INST_AVALA/COD_INST"],
                      "DB":"__CVLAC__",
                      "TABLES":[{'EN_INSTITUCION': [
                          # pais
                          {"KEYS": ["SGL_PAIS"],
                           "DB":"__CVLAC__",
                           "TABLES":[{'EN_PAIS': None}]},

                      ]}]},
                     # Idioma
                     {"KEYS": ["SGL_IDIOMA"],
                         "DB":"__CVLAC__",
                         "TABLES":[{'EN_IDIOMA': None}]},

                     # Prod type
                     # Prod type level 3
                     {"KEYS": ["COD_TIPO_PRODUCTO"],
                         "DB":"__CVLAC__",
                         "TABLES":[{'EN_TIPO_PRODUCTO': [
                             # Prod type level 2
                             {"KEYS": ["COD_TIPO_PRODUCTO_PADRE/COD_TIPO_PRODUCTO"],
                              "DB":"__CVLAC__",
                              "TABLES":[{'EN_TIPO_PRODUCTO': [
                                  # Prod type level 1
                                  {"KEYS": ["COD_TIPO_PRODUCTO_PADRE/COD_TIPO_PRODUCTO"],
                                   "DB":"__CVLAC__",
                                   "TABLES":[{'EN_TIPO_PRODUCTO': [
                                       # Prod type level 0
                                       {"KEYS": ["COD_TIPO_PRODUCTO_PADRE/COD_TIPO_PRODUCTO"],
                                        "DB":"__CVLAC__",
                                        "TABLES":[{'EN_TIPO_PRODUCTO': None}
                                                  ]}
                                   ]}
                                  ]}

                              ]}
                             ]},

                         ]}
                     ]},
                     # Proyecto diecto de producto
                     {"KEYS": ["COD_RH", "COD_PRODUCTO"],
                         "DB":"__CVLAC__",
                         "TABLES":[{'RE_PROYECTO_PRODUCTO':
                                    [
                                        # Tabla principal muere
                                        {"KEYS": ["COD_RH", "COD_PROYECTO"],
                                         "DB":"__CVLAC__",
                                         "TABLES":[{'EN_PROYECTO': None}]},

                                    ]}]},

                     # Grupo x Producto
                     {"KEYS": ["COD_RH", "COD_PRODUCTO"],
                      "DB":"__GRUPLAC__",
                      "TABLES":[{'EN_PRODUCTO_GR': [
                          # Grupo
                          {"KEYS": ["NRO_ID_GRUPO"],
                           "DB":"__GRUPLAC__",
                           "TABLES":[{"EN_GRUPO_PESQUISA": [
                               # re_institucion
                               {"KEYS": ["NRO_ID_GRUPO"],
                                "DB":"__GRUPLAC__",
                                "TABLES":[{'RE_GRUPO_INSTITUCION': [
                                    # institucion
                                    {"KEYS": ["COD_INST"],
                                     "DB":"__CVLAC__",
                                     "TABLES":[{'EN_INSTITUCION': [
                                         # pais
                                         {"KEYS": ["SGL_PAIS"],
                                          "DB":"__CVLAC__",
                                          "TABLES":[{'EN_PAIS': None}]},
                                     ]}
                                    ]}
                                ]}
                               ]},
                               # Area reconocimiento level 2 (tiene 3 niveles máximo) (es con COD_RH_AREA???)
                               {"KEYS": ['COD_RH_AREA/COD_RH', 'COD_AREA_CONHEC/COD_AREA_CONOCIMIENTO'],
                                   "DB":"__CVLAC__",
                                   "TABLES":[
                                   {"EN_AREA_CONOCIMIENTO": [
                                       # Area reconocimiento level 1
                                       {"KEYS": ['COD_RH_PADRE/COD_RH', "COD_AREA_PADRE/COD_AREA_CONOCIMIENTO"],
                                        "DB":"__CVLAC__",
                                        "TABLES":[{'EN_AREA_CONOCIMIENTO': [
                                            # Area reconocimiento level 0
                                            {"KEYS": ['COD_RH_PADRE/COD_RH', "COD_AREA_PADRE/COD_AREA_CONOCIMIENTO"],
                                             "DB":"__CVLAC__",
                                             "TABLES":[{'EN_AREA_CONOCIMIENTO': None}]},
                                        ]}
                                       ]},

                                   ]}
                               ]},
                           ]},
                          ]},
                          # Proyectos pasando por grupo
                          {"KEYS": ['NRO_ID_GRUPO', 'SEQ_PRODUCTO/SEQ_PRODUCAO'],
                              "DB":"__GRUPLAC__",
                              "TABLES":[
                              {"RE_PROYECTO_PRODUCTO_GR": [{"KEYS": ["NRO_ID_GRUPO", "SEQ_PROJETO"],
                                                           "DB":"__GRUPLAC__",
                                                            "TABLES":[
                                  {"EN_PROYECTO_GR": None}
                              ]}
                              ]}
                          ]},
                      ]}
                     ]},
                     # Recurso humano otro
                     {"KEYS": ["COD_RH", "COD_PRODUCTO"],
                         "DB":"__CVLAC__",
                         "TABLES":[{'RE_PRODUCTO_RECURSO_HUM_OTRO': [{"KEYS": ["COD_RH/COD_RH_CREA", "COD_RH_OTRO"],
                                                                      "DB":"__CVLAC__",
                                                                      "TABLES":[{'EN_RECURSO_HUMANO_OTRO': None}
                                                                                ]}
                                                                     ]}
                                   ]},
                     # Prod tecnica (Details)
                     {"KEYS": ["COD_RH", "COD_PRODUCTO"],
                         "DB":"__CVLAC__",
                         "TABLES":[{'EN_PROD_TECNICA':
                                    [{"KEYS": ["COD_RH", "COD_PRODUCTO"],
                                      "DB":"__CVLAC__",
                                      "TABLES":[
                                        # Producto Tecnilogico
                                        {'EN_PROD_TECNOLOGICO': [
                                            # Editorial
                                            {"KEYS": ["COD_EDITORIAL"],
                                             "DB":"__CVLAC__",
                                             "TABLES":[{'EN_EDITORIAL': None}]},
                                            # Editorial others
                                            {"KEYS": ["COD_RH", "COD_EDITORIAL_OTRO/COD_EDITORIAL"],
                                             "DB":"__CVLAC__",
                                             "TABLES":[{'EN_EDITORIAL_OTRO': None}]},

                                        ]},
                                        # secreto industrial
                                        {'EN_SECRETO_INDUSTRIAL': [
                                            # Institucion
                                            {"KEYS": ["COD_INSTITUCION/COD_INST"],
                                             "DB":"__CVLAC__",
                                             "TABLES":[{'EN_INSTITUCION': [
                                                 # pais
                                                 {"KEYS": ["SGL_PAIS"],
                                                  "DB":"__CVLAC__",
                                                  "TABLES":[{'EN_PAIS': None}]},
                                             ]}]},
                                            # Institucion otra
                                            {"KEYS": ["COD_RH", "COD_INST_OTRO/COD_INST"],
                                             "DB":"__CVLAC__",
                                             "TABLES":[{'EN_INSTITUCION_OTRA': [
                                                 # municipio
                                                 {"KEYS": ["COD_RH_MUNICIPIO", "COD_MUNICIPIO"],
                                                  "DB":"__CVLAC__",
                                                  "TABLES":[{'EN_MUNICIPIO': [
                                                      # departamento
                                                      {"KEYS": ["SGL_PAIS", "SGL_DEPARTAMENTO"],
                                                       "DB":"__CVLAC__",
                                                       "TABLES":[{'EN_DEPARTAMENTO': [
                                                           # pais
                                                           {"KEYS": ["SGL_PAIS"],
                                                            "DB":"__CVLAC__",
                                                            "TABLES":[{'EN_PAIS': None}]},

                                                       ]}]},
                                                  ]}]},

                                             ]}]},
                                        ]},
                                        # software (No tiene sub tablas)
                                        {'EN_PROD_SOFTWARE': None},
                                        # Registro
                                        {'EN_REGISTRO': [
                                            # Institucion
                                            {"KEYS": ["COD_INSTITUCION/COD_INST"],
                                             "DB":"__CVLAC__",
                                             "TABLES":[{'EN_INSTITUCION': [
                                                 # pais
                                                 {"KEYS": ["SGL_PAIS"],
                                                  "DB":"__CVLAC__",
                                                  "TABLES":[{'EN_PAIS': None}]},

                                             ]}]},
                                            # Institucion otra
                                            {"KEYS": ["COD_RH", "COD_INST_OTRO/COD_INST"],
                                             "DB":"__CVLAC__",
                                             "TABLES":[{'EN_INSTITUCION_OTRA': [
                                                 # municipio
                                                 {"KEYS": ["COD_RH_MUNICIPIO", "COD_MUNICIPIO"],
                                                  "DB":"__CVLAC__",
                                                  "TABLES":[{'EN_MUNICIPIO': [
                                                      # departamento
                                                      {"KEYS": ["SGL_PAIS", "SGL_DEPARTAMENTO"],
                                                       "DB":"__CVLAC__",
                                                       "TABLES":[{'EN_DEPARTAMENTO': [
                                                           # pais
                                                           {"KEYS": ["SGL_PAIS"],
                                                            "DB":"__CVLAC__",
                                                            "TABLES":[{'EN_PAIS': None}]},

                                                       ]}]},
                                                  ]}]},

                                             ]}]},

                                        ]},
                                        # prod vegetal (No tiene sub tablas)
                                        {'EN_PROD_VEGETAL': None},
                                        # Producto Norma
                                        {'EN_PROD_NORMA': [
                                            # Editorial
                                            {"KEYS": ["COD_EDITORIAL"],
                                             "DB":"__CVLAC__",
                                             "TABLES":[{'EN_EDITORIAL': None}]},
                                            # Editorial others
                                            {"KEYS": ["COD_RH", "COD_EDITORIAL_OTRO/COD_EDITORIAL"],
                                             "DB":"__CVLAC__",
                                             "TABLES":[{'EN_EDITORIAL_OTRO': None}]},

                                        ]},
                                        # Patente (patente es tabla primaria, no se va mas en profuncidad aca)
                                        {'EN_PATENTE': None},

                                    ]},

                                    ]}
                                   ]},
                     # Prod artistica (Details)
                     {"KEYS": ["COD_RH", "COD_PRODUCTO"],
                      "DB":"__CVLAC__",
                      "TABLES":[{'EN_PROD_ARTISTICA': [
                          # prod artistica detalles
                          {"KEYS": ["COD_RH", "COD_PRODUCTO"],
                           "DB":"__CVLAC__",
                           "TABLES":[{'EN_PROD_ARTISTICA_DETALLE': None}
                                     ]},
                          # Area reconocimiento level 2 (tiene 3 niveles máximo)
                          {"KEYS": ['COD_RH_AREA_CON/COD_RH', 'COD_AREA_CONOCIMIENTO'],
                           "DB":"__CVLAC__",
                           "TABLES":[
                               {"EN_AREA_CONOCIMIENTO": [
                                   # Area reconocimiento level 1
                                   {"KEYS": ['COD_RH_PADRE/COD_RH', "COD_AREA_PADRE/COD_AREA_CONOCIMIENTO"],
                                    "DB":"__CVLAC__",
                                    "TABLES":[{'EN_AREA_CONOCIMIENTO': [
                                        # Area reconocimiento level 0
                                        {"KEYS": ['COD_RH_PADRE/COD_RH', "COD_AREA_PADRE/COD_AREA_CONOCIMIENTO"],
                                         "DB":"__CVLAC__",
                                         "TABLES":[{'EN_AREA_CONOCIMIENTO': None}]},
                                    ]}
                                   ]},

                               ]}
                          ]},
                      ]}
                     ]},
                     # Tesis orientada (Details)
                     {"KEYS": ["COD_RH", "COD_PRODUCTO"],
                      "DB":"__CVLAC__",
                      "TABLES":[{'EN_TESIS_ORIENTADA': [
                          # Programa academico
                          {"KEYS": ["COD_RH_PROGRAMA/COD_RH", "COD_PROGRAMA_ACADEMICO"],
                           "DB":"__CVLAC__",
                           "TABLES":[{'EN_PROGRAMA_ACADEMICO': None}]},
                          # Institucion (HAY DOS OPCIONES ACA! COD_INST y COD_INSTITUCION)
                          # tomado COD_INSTITUCION por que hay más registros
                          {"KEYS": ["COD_INSTITUCION/COD_INST"],
                           "DB":"__CVLAC__",
                           "TABLES":[{'EN_INSTITUCION': [
                               # pais
                               {"KEYS": ["SGL_PAIS"],
                                "DB":"__CVLAC__",
                                "TABLES":[{'EN_PAIS': None}]},
                           ]}]},


                      ]}]},
                     # Producion audiovisual (Details)
                     {"KEYS": ["COD_RH", "COD_PRODUCTO"],
                         "DB":"__CVLAC__",
                         "TABLES":[{'EN_PROD_AUDIOVISUAL': [
                             # municipio
                             {"KEYS": ["COD_RH_MUNICIPIO", "COD_MUNICIPIO"],
                              "DB":"__CVLAC__",
                              "TABLES":[{'EN_MUNICIPIO': [
                                  # departamento
                                  {"KEYS": ["SGL_PAIS", "SGL_DEPARTAMENTO"],
                                   "DB":"__CVLAC__",
                                   "TABLES":[{'EN_DEPARTAMENTO': [
                                       # pais
                                       {"KEYS": ["SGL_PAIS"],
                                        "DB":"__CVLAC__",
                                        "TABLES":[{'EN_PAIS': None}]},

                                   ]}]},
                              ]}]},


                         ]}]},
                     # Partitura (Details)
                     {"KEYS": ["COD_RH", "COD_PRODUCTO"],
                         "DB":"__CVLAC__",
                         "TABLES":[{'EN_PROD_PARTITURA': [
                             # Editorial
                             {"KEYS": ["COD_EDITORIAL"],
                              "DB":"__CVLAC__",
                              "TABLES":[{'EN_EDITORIAL': None}]},
                             # Editorial others
                             {"KEYS": ["COD_RH", "COD_EDITORIAL_OTRO/COD_EDITORIAL"],
                              "DB":"__CVLAC__",
                              "TABLES":[{'EN_EDITORIAL_OTRO': None}]},
                         ]}]},
                     # Capitulo libro (Details)
                     {"KEYS": ["COD_RH", "COD_PRODUCTO"],
                         "DB":"__CVLAC__",
                         "TABLES":[{'EN_PROD_CAPITULO_LIBRO': [
                             # Libro otro
                             {"KEYS": ["COD_RH", "COD_LIBRO_OTRO/COD_PRODUCTO"],
                              "DB":"__CVLAC__",
                              "TABLES":[{'EN_LIBRO_OTRO': [
                                  # Editorial
                                  {"KEYS": ["COD_EDITORIAL"],
                                   "DB":"__CVLAC__",
                                   "TABLES":[{'EN_EDITORIAL': None}]},
                                  # Editorial others
                                  {"KEYS": ["COD_RH", "COD_EDITORIAL_OTRO/COD_EDITORIAL"],
                                   "DB":"__CVLAC__",
                                   "TABLES":[{'EN_EDITORIAL_OTRO': None}]},
                                  # revista
                                  {"KEYS": ["COD_REVISTA"],
                                   "DB":"__CVLAC__",
                                   "TABLES":[{'EN_REVISTA': [
                                       # editorial
                                       {"KEYS": ["COD_EDITORIAL"],
                                        "DB":"__CVLAC__",
                                        "TABLES":[{'EN_EDITORIAL': None}
                                                  ]}
                                   ]}
                                  ]},
                                  # tipo de producto nivel 3
                                  {"KEYS": ["COD_TIPO_PRODUCTO"],
                                   "DB":"__CVLAC__",
                                   "TABLES":[{'EN_TIPO_PRODUCTO': [
                                       # tipo de producto nivel 2
                                       {"KEYS": ["COD_TIPO_PRODUCTO_PADRE/COD_TIPO_PRODUCTO"],
                                        "DB":"__CVLAC__",
                                        "TABLES":[{'EN_TIPO_PRODUCTO': [
                                            # tipo de producto nivel 1
                                            {"KEYS": ["COD_TIPO_PRODUCTO_PADRE/COD_TIPO_PRODUCTO"],
                                             "DB":"__CVLAC__",
                                             "TABLES":[{'EN_TIPO_PRODUCTO': [
                                                 # tipo de producto nivel 0
                                                 {"KEYS": ["COD_TIPO_PRODUCTO_PADRE/COD_TIPO_PRODUCTO"],
                                                  "DB":"__CVLAC__",
                                                  "TABLES":[{'EN_TIPO_PRODUCTO': None}]},
                                             ]}]},

                                        ]}]},

                                   ]}]},

                              ]}]},


                         ]}]},
                     # libro (Details)
                     {"KEYS": ["COD_RH", "COD_PRODUCTO"],
                         "DB":"__CVLAC__",
                         "TABLES":[{'EN_LIBRO': [
                             # Editorial
                             {"KEYS": ["COD_EDITORIAL"],
                                   "DB":"__CVLAC__",
                                   "TABLES":[{'EN_EDITORIAL': None}]},
                             # Editorial others
                             {"KEYS": ["COD_RH", "COD_EDITORIAL_OTRO/COD_EDITORIAL"],
                              "DB":"__CVLAC__",
                                   "TABLES":[{'EN_EDITORIAL_OTRO': None}]},
                             # relacion idiomas
                             {"KEYS": ["COD_RH", "COD_PRODUCTOL"],
                              "DB":"__CVLAC__",
                                   "TABLES":[{'RE_LIBRO_IDIOMA': [
                                       # Idioma
                                       {"KEYS": ["SGL_IDIOMA"],
                                        "DB":"__CVLAC__",
                                        "TABLES":[{'EN_IDIOMA': None}]},

                                   ]}]},


                         ]}]},
                     # Cursos (Details)
                     {"KEYS": ["COD_RH", "COD_PRODUCTO"],
                      "DB":"__CVLAC__",
                      "TABLES":[{'EN_PROD_CURSO': [
                          # municipio
                          {"KEYS": ["COD_RH_MUNICIPIO", "COD_MUNICIPIO"],
                           "DB":"__CVLAC__",
                           "TABLES":[{'EN_MUNICIPIO': [
                               # departamento
                               {"KEYS": ["SGL_PAIS", "SGL_DEPARTAMENTO"],
                                "DB":"__CVLAC__",
                                "TABLES":[{'EN_DEPARTAMENTO': [
                                    # pais
                                    {"KEYS": ["SGL_PAIS"],
                                     "DB":"__CVLAC__",
                                     "TABLES":[{'EN_PAIS': None}]},

                                ]}]},
                           ]}]},
                          # Institucion (HAY DOS OPCIONES ACA TAMBIEN! COD_INST y COD_INSTITUCION)
                          # se tomo COD_INSTITUCION por que tiene mas registros
                          {"KEYS": ["COD_INSTITUCION/COD_INST"],
                           "DB":"__CVLAC__",
                           "TABLES":[{'EN_INSTITUCION': [
                               # pais
                               {"KEYS": ["SGL_PAIS"],
                                "DB":"__CVLAC__",
                                "TABLES":[{'EN_PAIS': None}]},
                           ]}]},
                          # Institucion otra
                          {"KEYS": ["COD_RH", "COD_INST_OTRO/COD_INST"],
                           "DB":"__CVLAC__",
                           "TABLES":[{'EN_INSTITUCION_OTRA': [
                               # municipio
                               {"KEYS": ["COD_RH_MUNICIPIO", "COD_MUNICIPIO"],
                                "DB":"__CVLAC__",
                                "TABLES":[{'EN_MUNICIPIO': [
                                    # departamento
                                    {"KEYS": ["SGL_PAIS", "SGL_DEPARTAMENTO"],
                                     "DB":"__CVLAC__",
                                     "TABLES":[{'EN_DEPARTAMENTO': [
                                         # pais
                                         {"KEYS": ["SGL_PAIS"],
                                          "DB":"__CVLAC__",
                                          "TABLES":[{'EN_PAIS': None}]},

                                     ]}]},
                                ]}]},

                           ]}]},

                      ]}]},
                     # capitulo de momoria (Details)
                     {"KEYS": ["COD_RH", "COD_PRODUCTO"],
                      "DB":"__CVLAC__",
                      "TABLES":[{'EN_PROD_CAP_MEMORIA': [
                          # Libro otro
                          {"KEYS": ["COD_RH", "COD_LIBRO_OTRO/COD_PRODUCTO"],
                              "DB":"__CVLAC__",
                              "TABLES":[{'EN_LIBRO_OTRO': [
                                  # Editorial
                                  {"KEYS": ["COD_EDITORIAL"],
                                   "DB":"__CVLAC__",
                                   "TABLES":[{'EN_EDITORIAL': None}]},
                                  # Editorial others
                                  {"KEYS": ["COD_RH", "COD_EDITORIAL_OTRO/COD_EDITORIAL"],
                                   "DB":"__CVLAC__",
                                   "TABLES":[{'EN_EDITORIAL_OTRO': None}]},
                                  # revista
                                  {"KEYS": ["COD_REVISTA"],
                                   "DB":"__CVLAC__",
                                   "TABLES":[{'EN_REVISTA': [
                                       # editorial
                                       {"KEYS": ["COD_EDITORIAL"],
                                        "DB":"__CVLAC__",
                                        "TABLES":[{'EN_EDITORIAL': None}
                                                  ]}
                                   ]}
                                  ]},
                                  # tipo de producto nivel 3
                                  {"KEYS": ["COD_TIPO_PRODUCTO"],
                                   "DB":"__CVLAC__",
                                   "TABLES":[{'EN_TIPO_PRODUCTO': [
                                       # tipo de producto nivel 2
                                       {"KEYS": ["COD_TIPO_PRODUCTO_PADRE/COD_TIPO_PRODUCTO"],
                                        "DB":"__CVLAC__",
                                        "TABLES":[{'EN_TIPO_PRODUCTO': [
                                            # tipo de producto nivel 1
                                            {"KEYS": ["COD_TIPO_PRODUCTO_PADRE/COD_TIPO_PRODUCTO"],
                                             "DB":"__CVLAC__",
                                             "TABLES":[{'EN_TIPO_PRODUCTO': [
                                                 # tipo de producto nivel 0
                                                 {"KEYS": ["COD_TIPO_PRODUCTO_PADRE/COD_TIPO_PRODUCTO"],
                                                  "DB":"__CVLAC__",
                                                  "TABLES":[{'EN_TIPO_PRODUCTO': None}]},
                                             ]}]},

                                        ]}]},

                                   ]}]},

                              ]}]},
                          # municipio
                          {"KEYS": ["COD_RH_MUNICIPIO", "COD_MUNICIPIO"],
                              "DB":"__CVLAC__",
                              "TABLES":[{'EN_MUNICIPIO': [
                                  # departamento
                                  {"KEYS": ["SGL_PAIS", "SGL_DEPARTAMENTO"],
                                   "DB":"__CVLAC__",
                                   "TABLES":[{'EN_DEPARTAMENTO': [
                                       # pais
                                       {"KEYS": ["SGL_PAIS"],
                                        "DB":"__CVLAC__",
                                        "TABLES":[{'EN_PAIS': None}]},

                                   ]}]},
                              ]}]},
                          # revista
                          {"KEYS": ["COD_REVISTA"],
                              "DB":"__CVLAC__",
                              "TABLES":[{'EN_REVISTA': [
                                  # editorial
                                  {"KEYS": ["COD_EDITORIAL"],
                                   "DB":"__CVLAC__",
                                   "TABLES":[{'EN_EDITORIAL': None}
                                             ]}
                              ]}
                          ]},
                          # revista otra
                          {"KEYS": ["COD_RH", "COD_REVISTA_OTRO/COD_REVISTA"],
                              "DB":"__CVLAC__",
                              "TABLES":[{'EN_REVISTA_OTRA': [
                                  # Editorial
                                  {"KEYS": ["COD_EDITORIAL"],
                                   "DB":"__CVLAC__",
                                   "TABLES":[{'EN_EDITORIAL': None}
                                             ]},
                                  # Editorial otro
                                  {"KEYS": ["COD_RH", "COD_EDITORIAL_OTRO/COD_EDITORIAL"],
                                   "DB":"__CVLAC__",
                                   "TABLES":[{'EN_EDITORIAL_OTRO': None}
                                             ]},
                              ]}
                          ]},

                      ]}]},

                     # Prod Articulos (Details)
                     {"KEYS": ["COD_RH", "COD_PRODUCTO"],
                         "DB":"__CVLAC__",
                         "TABLES":[{'EN_PROD_ARTICULO': [
                             # revista
                             {"KEYS": ["COD_REVISTA"],
                              "DB":"__CVLAC__",
                              "TABLES":[{'EN_REVISTA': [
                                  # editorial
                                  {"KEYS": ["COD_EDITORIAL"],
                                   "DB":"__CVLAC__",
                                   "TABLES":[{'EN_EDITORIAL': None}
                                             ]}
                              ]}
                             ]},
                             # revista otra
                             {"KEYS": ["COD_RH", "COD_REVISTA_OTRO/COD_REVISTA"],
                              "DB":"__CVLAC__",
                              "TABLES":[{'EN_REVISTA_OTRA': [
                                  # Editorial
                                  {"KEYS": ["COD_EDITORIAL"],
                                   "DB":"__CVLAC__",
                                   "TABLES":[{'EN_EDITORIAL': None}
                                             ]},
                                  # Editorial otro
                                  {"KEYS": ["COD_RH", "COD_EDITORIAL_OTRO/COD_EDITORIAL"],
                                   "DB":"__CVLAC__",
                                   "TABLES":[{'EN_EDITORIAL_OTRO': None}
                                             ]},
                              ]}
                             ]},
                         ]}
                     ]},
                     # Prod biblio (Details)
                     {"KEYS": ["COD_RH", "COD_PRODUCTO"],
                      "DB":"__CVLAC__",
                      "TABLES":[{'EN_PROD_BIBLIO': [
                          # revista
                          {"KEYS": ["COD_REVISTA"],
                           "DB":"__CVLAC__",
                           "TABLES":[{'EN_REVISTA': [
                               # editorial
                               {"KEYS": ["COD_EDITORIAL"],
                                "DB":"__CVLAC__",
                                "TABLES":[{'EN_EDITORIAL': None}
                                          ]}
                           ]}
                          ]},
                          # revista otra
                          {"KEYS": ["COD_RH", "COD_REVISTA_OTRO/COD_REVISTA"],
                              "DB":"__CVLAC__",
                              "TABLES":[{'EN_REVISTA_OTRA': [
                                  # Editorial
                                  {"KEYS": ["COD_EDITORIAL"],
                                   "DB":"__CVLAC__",
                                   "TABLES":[{'EN_EDITORIAL': None}
                                             ]},
                                  # Editorial otro
                                  {"KEYS": ["COD_RH", "COD_EDITORIAL_OTRO/COD_EDITORIAL"],
                                   "DB":"__CVLAC__",
                                   "TABLES":[{'EN_EDITORIAL_OTRO': None}
                                             ]},
                              ]}
                          ]},
                      ]}
                     ]},
                     # Re-Sector Apliación
                     {"KEYS": ["COD_RH", "COD_PRODUCTO"],
                      "DB":"__CVLAC__",
                      "TABLES":[{'RE_PRODUCTO_SECTOR_APL': [
                          # sector aplicación nivel 2
                          {"KEYS": ["COD_SECTOR_APLICACION"],
                           "DB":"__CVLAC__",
                           "TABLES":[{'EN_SECTOR_APLICACION': [
                               # sector aplicación nivel 1
                               {"KEYS": ["COD_SECT_APLIC_PADRE/COD_SECTOR_APLICACION"],
                                "DB":"__CVLAC__",
                                "TABLES":[{'EN_SECTOR_APLICACION': None}
                                          ]}
                           ]}
                          ]}
                      ]}

                     ]},
                     # Re-Palabra clave
                     {"KEYS": ["COD_RH", "COD_PRODUCTO"],
                      "DB":"__CVLAC__",
                      "TABLES":[{'RE_PRODUCTO_PALABRA_CLA': [
                          # Palabra clave
                          {"KEYS": ["COD_RH", "COD_PALABRA_CLAVE"],
                           "DB":"__CVLAC__",
                           "TABLES":[{'EN_PALABRA_CLAVE': None}
                                     ]}
                      ]}

                     ]},
                     # Re-Evento (details)
                     {"KEYS": ["COD_RH", "COD_PRODUCTO"],
                      "DB":"__CVLAC__",
                      "TABLES":[{'RE_PRODUCTO_EVENTO': [
                          # Evento (hasta acá llega evento, ya que es una tabla principal)
                          {"KEYS": ["COD_RH", "COD_EVENTO"],
                           "DB":"__CVLAC__",
                           "TABLES":[{'EN_EVENTO': None}
                                     ]}
                      ]}

                     ]},
                     # Re-Comunidad (details)
                     {"KEYS": ["COD_RH", "COD_PRODUCTO"],
                      "DB":"__CVLAC__",
                      "TABLES":[{'RE_PRODUCTO_COMUNIDAD': [
                          # Comunidad
                          {"KEYS": ["COD_RH", "COD_COMUNIDAD"],
                           "DB":"__CVLAC__",
                           "TABLES":[{'EN_COMUNIDAD': [
                               # Municipio
                               {"KEYS": ["COD_RH_MUNICIPIO", "COD_MUNICIPIO"],
                                "DB":"__CVLAC__",
                                "TABLES":[{'EN_MUNICIPIO': None}]},
                               # Re-proyecto comunidad
                               {"KEYS": ["COD_RH", "COD_COMUNIDAD"],
                                "DB":"__CVLAC__",
                                "TABLES":[{'RE_PROYECTO_COMUNIDAD': [
                                    # proyecto (Aca muere proyecto por que es tabla primaria)
                                    {"KEYS": ["COD_RH", "COD_PROYECTO"],
                                     "DB":"__CVLAC__",
                                     "TABLES":[{"EN_PROYECTO": None}]}
                                ]}]},
                               # Re-Red-comunidad
                               {"KEYS": ["COD_RH", "COD_COMUNIDAD"],
                                "DB":"__CVLAC__",
                                "TABLES":[{'RE_RED_COMUNIDAD': [
                                    # red (Aca muere Red por que es tabla primaria)
                                    {"KEYS": ["COD_RH", "COD_RED"],
                                     "DB":"__CVLAC__",
                                     "TABLES":[{"EN_RED": None}]}
                                ]}]},

                           ]}
                          ]},
                      ]}

                     ]},
                 ]}
                 ]}



##
# product fields
##

product_fields = {}
product_fields["EN_PRODUCTO"] = {"alias": "product"}
product_fields["EN_PRODUCTO"]["fields"] = {
}

product_fields["EN_INSTITUCION"] = {"alias": "institution"}
product_fields["EN_INSTITUCION"]["fields"] = {
}

product_fields["EN_RECURSO_HUMANO"] = {"alias": "author"}
product_fields["EN_RECURSO_HUMANO"]["fields"] = {
}

product_fields["EN_GRUPO_PESQUISA"] = {"alias": "group"}
product_fields["EN_GRUPO_PESQUISA"]["fields"] = {
}

product_fields["EN_AREA_CONOCIMIENTO"] = {"alias": "knowledge_area"}
product_fields["EN_AREA_CONOCIMIENTO"]["fields"] = {
}

product_fields["EN_RECURSO_HUMANO_OTRO"] = {"alias": "author_others"}
product_fields["EN_RECURSO_HUMANO_OTRO"]["fields"] = {
}

product_fields["EN_MUNICIPIO"] = {"alias": "city"}
product_fields["EN_MUNICIPIO"]["fields"] = {
}

product_fields["EN_PROYECTO_GR"] = {"alias": ""}
product_fields["EN_PROYECTO_GR"]["fields"] = {
}

product_fields["EN_PRODUCTO_GR"] = {"alias": "", }
product_fields["EN_PRODUCTO_GR"]["fields"] = {}

product_fields["EN_TIPO_PRODUCTO"] = {"alias": "product_type"}
product_fields["EN_TIPO_PRODUCTO"]["fields"] = {
}

product_fields["EN_PROYECTO"] = {"alias": "project"}
product_fields["EN_PROYECTO"]["fields"] = {
}

product_fields["EN_PROD_TECNICA"] = {
    "alias": "technical", "sub_section": "details"}
product_fields["EN_PROD_TECNICA"]["fields"] = {
}

product_fields["EN_PATENTE"] = {"alias": "patent", "sub_section": "details"}
product_fields["EN_PATENTE"]["fields"] = {
}

product_fields["EN_PROD_TECNOLOGICO"] = {
    "alias": "tech_product", "sub_section": "details"}
product_fields["EN_PROD_TECNOLOGICO"]["fields"] = {
}

product_fields["EN_SECRETO_INDUSTRIAL"] = {
    "alias": "industrial_secret", "sub_section": "details"}
product_fields["EN_SECRETO_INDUSTRIAL"]["fields"] = {
}

product_fields["EN_PROD_SOFTWARE"] = {
    "alias": "software", "sub_section": "details"}
product_fields["EN_PROD_SOFTWARE"]["fields"] = {
}


product_fields["EN_REGISTRO"] = {"alias": "register", "sub_section": "details"}
product_fields["EN_REGISTRO"]["fields"] = {
}

product_fields["EN_PROD_NORMA"] = {"alias": "rule", "sub_section": "details"}
product_fields["EN_PROD_NORMA"]["fields"] = {
}

product_fields["EN_PROD_VEGETAL"] = {
    "alias": "plant_product", "sub_section": "details"}
product_fields["EN_PROD_VEGETAL"]["fields"] = {
}

product_fields["EN_PROD_ARTISTICA"] = {
    "alias": "prod_art", "sub_section": "details"}
product_fields["EN_PROD_ARTISTICA"]["fields"] = {
}

product_fields["EN_PROD_ARTISTICA_DETALLE"] = {
    "alias": "prod_art_detail", "sub_section": "details"}
product_fields["EN_PROD_ARTISTICA_DETALLE"]["fields"] = {
}

product_fields["EN_PROD_OBRA_ARTISTICA"] = {
    "alias": "prod_artwork", "sub_section": "details"}
product_fields["EN_PROD_OBRA_ARTISTICA"]["fields"] = {
}

product_fields["EN_TESIS_ORIENTADA"] = {
    "alias": "oriented_thesis", "sub_section": "details"}
product_fields["EN_TESIS_ORIENTADA"]["fields"] = {
}

product_fields["EN_PROD_AUDIOVISUAL"] = {
    "alias": "audiovisual", "sub_section": "details"}
product_fields["EN_PROD_AUDIOVISUAL"]["fields"] = {
}

product_fields["EN_PROD_PARTITURA"] = {
    "alias": "music_sheet", "sub_section": "details"}
product_fields["EN_PROD_PARTITURA"]["fields"] = {
}

product_fields["EN_PROD_CAPITULO_LIBRO"] = {
    "alias": "book_chapter", "sub_section": "details"}
product_fields["EN_PROD_CAPITULO_LIBRO"]["fields"] = {
}

product_fields["EN_PROD_NORMA"] = {"alias": "rule", "sub_section": "details"}
product_fields["EN_PROD_NORMA"]["fields"] = {
}
product_fields["EN_PROD_CURSO"] = {"alias": "course", "sub_section": "details"}
product_fields["EN_PROD_CURSO"]["fields"] = {
}
product_fields["EN_PROD_CAP_MEMORIA"] = {
    "alias": "memory_chapter", "sub_section": "details"}
product_fields["EN_PROD_CAP_MEMORIA"]["fields"] = {
}


product_fields["EN_PROD_ARTICULO"] = {
    "alias": "article", "sub_section": "details"}
product_fields["EN_PROD_ARTICULO"]["fields"] = {
}
product_fields["EN_LIBRO"] = {"alias": "book", "sub_section": "details"}
product_fields["EN_LIBRO"]["fields"] = {
}

product_fields["EN_REVISTA"] = {"alias": "journal", "sub_section": "details"}
product_fields["EN_REVISTA"]["fields"] = {
}

product_fields["EN_REVISTA_OTRA"] = {
    "alias": "journal_others", "sub_section": "details"}
product_fields["EN_REVISTA_OTRA"]["fields"] = {
}

product_fields["EN_EDITORIAL"] = {
    "alias": "editorial", "sub_section": "details"}
product_fields["EN_EDITORIAL"]["fields"] = {
}

product_fields["EN_EDITORIAL_OTRO"] = {
    "alias": "editorial_others", "sub_section": "details"}
product_fields["EN_EDITORIAL_OTRO"]["fields"] = {
}

product_fields["EN_SECTOR_APLICACION"] = {
    "alias": "application_sector", "sub_section": "details"}
product_fields["EN_SECTOR_APLICACION"]["fields"] = {
}
product_fields["EN_PALABRA_CLAVE"] = {
    "alias": "keywords", "sub_section": "details"}
product_fields["EN_PALABRA_CLAVE"]["fields"] = {
}

product_fields["EN_NIVEL_FORMACION"] = {"alias": "studies_level"}
product_fields["EN_NIVEL_FORMACION"]["fields"] = {
}

product_fields["EN_INSTITUCION_OTRA"] = {"alias": "institution_other"}
product_fields["EN_INSTITUCION_OTRA"]["fields"] = {
}
product_fields["EN_PAIS"] = {"alias": "country"}
product_fields["EN_PAIS"]["fields"] = {
}
product_fields["EN_IDIOMA"] = {"alias": "language"}
product_fields["EN_IDIOMA"]["fields"] = {
}

product_fields["EN_DEPARTAMENTO"] = {"alias": "department"}
product_fields["EN_DEPARTAMENTO"]["fields"] = {
}

product_fields["EN_LIBRO_OTRO"] = {"alias": "book_other"}
product_fields["EN_LIBRO_OTRO"]["fields"] = {
}
product_fields["EN_EVENTO"] = {"alias": "event", "sub_section": "details"}
product_fields["EN_EVENTO"]["fields"] = {
}

product_fields["EN_COMUNIDAD"] = {
    "alias": "community", "sub_section": "details"}
product_fields["EN_COMUNIDAD"]["fields"] = {
}
product_fields["EN_RED"] = {"alias": "network"}
product_fields["EN_RED"]["fields"] = {
}



# SIIU data model 2022
# SCHEMA version for modification on the relations, it is vertioned as well
from .graph_schema_project import graph_project

graph_schema = {"SIIU_MODEL": 2022}
graph_schema["MODELS"] = {}

graph_schema["MODELS"]["project"] = graph_project




graph_event = {"MAIN_TABLE": "EN_EVENTO",
               "CHECKPOINT": {"DB": "__CVLAC__", "KEYS": ["COD_RH", "COD_EVENTO"]},
               "SCHEMA_VERSION": 0.1,
               "GRAPH": [{"EN_EVENTO": [
                   # autor registrante
                   {"KEYS": ["COD_RH"],
                    "DB":"__CVLAC__",
                    "TABLES":[{'EN_RECURSO_HUMANO': [
                        # municipio
                        {"KEYS": ["COD_RH_MUN_NACIM/COD_RH_MUNICIPIO", "COD_MUN_NACIM/COD_MUNICIPIO"],
                              "DB":"__CVLAC__",
                              "TABLES":[{'EN_MUNICIPIO': [
                                  # departamento
                                  {"KEYS": ["SGL_PAIS", "SGL_DEPARTAMENTO"],
                                   "DB":"__CVLAC__",
                                   "TABLES":[{'EN_DEPARTAMENTO': [
                                       # pais
                                       {"KEYS": ["SGL_PAIS"],
                                        "DB":"__CVLAC__",
                                        "TABLES":[{'EN_PAIS': None}]},

                                   ]}]},
                              ]}]},
                        # level of studies
                        {"KEYS": ["COD_NIVEL_FORMACION"],
                         "DB":"__CVLAC__",
                              "TABLES":[{'EN_NIVEL_FORMACION': None}]},
                    ]},
                   ]},

                   # institucion registrante
                   {"KEYS": ["COD_INST_AVALA/COD_INST"],
                       "DB":"__CVLAC__",
                       "TABLES":[{'EN_INSTITUCION': [
                           # pais
                           {"KEYS": ["SGL_PAIS"],
                            "DB":"__CVLAC__",
                            "TABLES":[{'EN_PAIS': None}]},

                       ]}]},
                   # Re-Institucion
                   {"KEYS": ["COD_RH", "COD_EVENTO"],
                       "DB":"__CVLAC__",
                       "TABLES":[{'RE_INSTITUCION_EVENTO': [
                           # instituciones
                           {"KEYS": ["COD_RH", "COD_INSTITUCION/COD_INST"],
                            "DB":"__CVLAC__",
                            "TABLES":[{'EN_INSTITUCION_OTRA': None}
                                      ]}
                       ]}

                   ]},
                   # Re-Autor otros
                   {"KEYS": ["COD_RH", "COD_EVENTO"],
                       "DB":"__CVLAC__",
                       "TABLES":[{'RE_RH_O_EVENTO': [
                           # Autores otros
                           {"KEYS": ["COD_RH/COD_RH_CREA", "COD_RH_OTRO"],
                            "DB":"__CVLAC__",
                            "TABLES":[{'EN_RECURSO_HUMANO_OTRO': None}
                                      ]}

                       ]}

                   ]},
                   # Re-Comunidad
                   {"KEYS": ["COD_RH", "COD_EVENTO"],
                       "DB":"__CVLAC__",
                       "TABLES":[{'RE_EVENTO_COMUNIDAD':
                                  [
                                      # Comunidad
                                      {"KEYS": ["COD_RH", "COD_COMUNIDAD"],
                                       "DB":"__CVLAC__",
                                       "TABLES":[{'EN_COMUNIDAD': [
                                           # Municipio
                                           {"KEYS": ["COD_RH_MUNICIPIO", "COD_MUNICIPIO"],
                                            "DB":"__CVLAC__",
                                            "TABLES":[{'EN_MUNICIPIO': None}]},
                                           # Re-proyecto comunidad
                                           {"KEYS": ["COD_RH", "COD_COMUNIDAD"],
                                            "DB":"__CVLAC__",
                                            "TABLES":[{'RE_PROYECTO_COMUNIDAD': [
                                                # proyecto
                                                {"KEYS": ["COD_RH", "COD_PROYECTO"],
                                                 "DB":"__CVLAC__",
                                                 "TABLES":[{"EN_PROYECTO": None}]}
                                            ]}]},
                                           # Re-producto comunidad
                                           {"KEYS": ["COD_RH", "COD_COMUNIDAD"],
                                            "DB":"__CVLAC__",
                                            "TABLES":[{'RE_PRODUCTO_COMUNIDAD': [
                                                # producto
                                                {"KEYS": ["COD_RH", "COD_PRODUCTO"],
                                                 "DB":"__CVLAC__",
                                                 "TABLES":[{"EN_PRODUCTO": None}]}
                                            ]}]},

                                       ]}
                                      ]},

                                  ]}
                                 ]},

                   # Re-Grupo
                   {"KEYS": ["COD_RH", "COD_EVENTO"],
                       "DB":"__GRUPLAC__",
                       "TABLES":[{'RE_GRUPO_RH_EVENTO': [
                           # Grupo
                           {"KEYS": ["NRO_ID_GRUPO"],
                            "DB":"__GRUPLAC__",
                            "TABLES":[{"EN_GRUPO_PESQUISA": [
                                # re_institucion
                                {"KEYS": ["NRO_ID_GRUPO"],
                                 "DB":"__GRUPLAC__",
                                 "TABLES":[{'RE_GRUPO_INSTITUCION': [
                                     # institucion
                                     {"KEYS": ["COD_INST"],
                                      "DB":"__CVLAC__",
                                      "TABLES":[{'EN_INSTITUCION': None}
                                                ]}
                                 ]}
                                ]},
                                # Area reconocimiento level 2 (tiene 3 niveles máximo) (es con COD_RH_AREA???)
                                {"KEYS": ['COD_RH_AREA/COD_RH', 'COD_AREA_CONHEC/COD_AREA_CONOCIMIENTO'],
                                 "DB":"__CVLAC__",
                                 "TABLES":[
                                    {"EN_AREA_CONOCIMIENTO": [
                                        # Area reconocimiento level 1
                                        {"KEYS": ['COD_RH_PADRE/COD_RH', "COD_AREA_PADRE/COD_AREA_CONOCIMIENTO"],
                                         "DB":"__CVLAC__",
                                         "TABLES":[{'EN_AREA_CONOCIMIENTO': [
                                             # Area reconocimiento level 0
                                             {"KEYS": ['COD_RH_PADRE/COD_RH', "COD_AREA_PADRE/COD_AREA_CONOCIMIENTO"],
                                              "DB":"__CVLAC__",
                                              "TABLES":[{'EN_AREA_CONOCIMIENTO': None}]},
                                         ]}
                                        ]},

                                    ]}
                                ]},
                            ]},
                           ]}
                       ]}

                   ]},
                   # Re-Palabra clave
                   {"KEYS": ["COD_RH", "COD_EVENTO"],
                       "DB":"__CVLAC__",
                       "TABLES":[{'RE_EVENTO_PALABRA_CLA': [
                           # Palabra clave
                           {"KEYS": ["COD_RH", "COD_PALABRA_CLAVE"],
                            "DB":"__CVLAC__",
                            "TABLES":[{'EN_PALABRA_CLAVE': None}
                                      ]}
                       ]}

                   ]},

                   # Re-evento producto
                   {"KEYS": ["COD_RH", "COD_EVENTO"],
                       "DB":"__CVLAC__",
                       "TABLES":[{'RE_PRODUCTO_EVENTO': [
                           # producto  (aca muere por que producto es tabla principal)
                           {"KEYS": ["COD_RH", "COD_PRODUCTO"],
                            "DB":"__CVLAC__",
                            "TABLES":[{'EN_PRODUCTO': None}
                                      ]}
                       ]}
                   ]},

                   # Re-evento Area de conocimiento
                   {"KEYS": ["COD_RH/COD_RH_EVENTO", "COD_EVENTO"],
                       "DB":"__CVLAC__",
                       "TABLES":[
                           {'RE_EVENTO_AREA_CON': [
                               # producto  (aca muere por que producto es tabla principal)
                               {"KEYS": ["COD_RH_AREA_CON/COD_RH", "COD_AREA_CONOCIMIENTO"],
                                "DB":"__CVLAC__",
                                "TABLES":[
                                # Area reconocimiento level 2 (tiene 3 niveles máximo)
                                {"EN_AREA_CONOCIMIENTO": [
                                    # Area reconocimiento level 1
                                    {"KEYS": ['COD_RH_PADRE/COD_RH', "COD_AREA_PADRE/COD_AREA_CONOCIMIENTO"],
                                        "DB":"__CVLAC__",
                                        "TABLES":[{'EN_AREA_CONOCIMIENTO': [
                                            # Area reconocimiento level 0
                                            {"KEYS": ['COD_RH_PADRE/COD_RH', "COD_AREA_PADRE/COD_AREA_CONOCIMIENTO"],
                                             "DB":"__CVLAC__",
                                             "TABLES":[{'EN_AREA_CONOCIMIENTO': None}]},
                                        ]}
                                    ]},

                                ]}
                               ]}
                           ]}
                   ]},
                   # Re-Sector Apliación
                   {"KEYS": ["COD_RH", "COD_EVENTO"],
                       "DB":"__CVLAC__",
                       "TABLES":[{'RE_EVENTO_SECTOR_APL': [
                           # sector aplicación nivel 2
                           {"KEYS": ["COD_SECTOR_APLICACION"],
                            "DB":"__CVLAC__",
                            "TABLES":[{'EN_SECTOR_APLICACION': [
                                # sector aplicación nivel 1
                                {"KEYS": ["COD_SECT_APLIC_PADRE/COD_SECTOR_APLICACION"],
                                 "DB":"__CVLAC__",
                                 "TABLES":[{'EN_SECTOR_APLICACION': None}
                                           ]}
                            ]}
                           ]}
                       ]}

                   ]},
                   # Proyecto directo de evento
                   {"KEYS": ["COD_RH", "COD_EVENTO"],
                    "DB":"__CVLAC__",
                         "TABLES":[{'RE_EVENTO_PROYECTO':
                                    [{"KEYS": ["COD_RH", "COD_PROYECTO"],
                                      "DB":"__CVLAC__",
                                      "TABLES":[{'EN_PROYECTO': None}]},

                                     ]}]},
                   # Proyecto tipo
                   {"KEYS": ["TPO_EVENTO"],
                    "DB":"__CVLAC__",
                    "TABLES":[{'EN_TIPO_EVENTO': None}]},

               ]}
               ]}



graph_project = {
    "MAIN_TABLE": "SIIU_PROYECTO",
    "CHECKPOINT": {"DB": "BUPP", "KEYS": ["CODIGO"]},
    "SCHEMA_VERSION": 0.1,
    "GRAPH":[
        {
            "SIIU_PROYECTO":[

                {
                    "KEYS": ["CODIGO/PROYECTO"],
                    "DB":"BUPP",
                    "TABLES":[
                        {
                            "SIIU_COMPROMISO_POR_PROYECTO": [
                                {
                                    "KEYS": ["COMPROMISO/IDENTIFICADOR"],
                                    "DB":"BUPP",
                                    "TABLES": [
                                        {"SIIU_COMPROMISO": None}
                                    ]
                                }
                            ]
                        },
                        {
                            "SIIU_ESTADO_PROYECTO": [
                                {
                                    "KEYS": ["DOCUMENTO_SOPORTE/IDENTIFICADOR"],
                                    "DB":"BUPP",
                                    "TABLES": [
                                        {"SIIU_DOCUMENTO_SOPORTE": None}
                                    ]
                                }
                            ]
                        },
                        {
                            "SIIU_AVAL_APROBACION": [
                                {
                                    "KEYS": ["DOCUMENTO_SOPORTE/IDENTIFICADOR"],
                                    "DB":"BUPP",
                                    "TABLES": [
                                        {"SIIU_DOCUMENTO_SOPORTE": None}
                                    ]
                                }
                            ]
                        },
                        {"SIIU_ACTUALIZACION_PROYECTO": None},
                        {
                            "SIIU_EVALUACION_TECNICA": [
                                {
                                    "KEYS": ["ETAPA_PROCESO/IDENTIFICADOR"],
                                    "DB":"BUPP",
                                    "TABLES": [
                                        {"SIIU_ETAPA_PROCESO_SELECCION": None}
                                    ]
                                }
                            ]
                        },
                        {
                            "SIIU_EVALUACION_CIENTIFICA": [
                                {
                                    "KEYS": ["EVALUADOR/IDENTIFICADOR"],
                                    "DB":"BUPP",
                                    "TABLES": [
                                        {
                                            "SIIU_EVALUADOR_RECOMENDADO": [
                                                {
                                                    "KEYS": ["EVALUADOR/IDENTIFICADOR"],
                                                    "DB":"BUPP",
                                                    "TABLES": [
                                                        {"SIIU_EVALUADOR": None}
                                                    ]
                                                }
                                            ]
                                        }
                                    ]  
                                }
                            ]
                        },
                        {
                            "SIIU_PARTICIPANTE_PROYECTO": [
                                {
                                    "KEYS": ["PERSONA_NATURAL/IDENTIFICACION"],
                                    "DB":"BUPP",
                                    "TABLES": [
                                        {"SIIU_PERSONA_NATURAL": None}
                                    ]
                                },
                                {
                                    "KEYS": ["ROL_PARTICIPANTE_PROYECTO/IDENTIFICADOR"],
                                    "DB":"BUPP",
                                    "TABLES":[
                                        {"SIIU_ROL_PARTICIPANTE_PROYECTO": None}
                                    ]
                                },
                                {
                                    "KEYS": ["GRUPO/IDENTIFICADOR"],
                                    "DB":"BUPP",
                                    "TABLES":[
                                        {"SIIU_GRUPO": None}
                                    ]
                                }
                            ]

                        },
                        {
                            "SIIU_APORTANTE_PROYECTO": [
                                {
                                    "KEYS": ["PERSONA_JURIDICA/NIT"],
                                    "DB":"BUPP",
                                    "TABLES": [
                                        {"SIIU_PERSONA_JURIDICA": None}
                                    ]
                                    
                                },
                                {
                                    "KEYS": ["GRUPO/IDENTIFICADOR"],
                                    "DB":"BUPP",
                                    "TABLES": [
                                        {"SIIU_GRUPO": None}
                                    ]
                                },
                                {
                                    "KEYS": ["IDENTIFICADOR/APORTANTE"],
                                    "DB":"BUPP",
                                    "TABLES": [
                                        {"SIIU_SEGUIMIENTO_APORTANTE": None},
                                        {"SIIU_SEGUIMIENTO_PRESUPUESTO": None}
                                    ]
                                },
                                {
                                    "KEYS": ["IDENTIFICADOR/APORTANTE_PROYECTO"],
                                    "DB":"BUPP",
                                    "TABLES": [
                                        {
                                            "SIIU_MODIFICACION_PRESUPUESTAL": [
                                                {
                                                    "KEYS": ["IDENTIFICADOR/MODIFICACION_PRESUPUESTAL"],
                                                    "DB":"BUPP",
                                                    "TABLES": [
                                                        {"SIIU_DETALLE_MODIF_PPTAL": None}
                                                    ]
                                                }
                                            ]
                                        },
                                    ]
                                }
                            ]
                        },
                        {
                            "SIIU_TEXTO_DESCRIPTIVO": [
                                {
                                    "KEYS": ["TEXTO_SOLICITADO/IDENTIFICADOR"],
                                    "DB":"BUPP",
                                    "TABLES": [
                                        {"SIIU_TEXTO_SOLICITADO": None}
                                    ]
                                }
                            ]
                        },
                        {"SIIU_SEGUIMIENTO_PPTO_INICIAL": None},
                        {
                            "SMAP_SOLICITUD_ADM": [
                                {
                                    "KEYS": ["ID/ID_SOLICITUD_ADM"],
                                    "DB":"BUPP",
                                    "TABLES": [
                                        {"SMAP_SOL_ADICION_PRESUPUESTAL": None},
                                        {"SMAP_SOLICITUD_CAMBIO_RUBRO": None}
                                    ]
                                }
                            ]
                        }
                    ]
            
                },
                {
                    "KEYS": ["CODIGO/CODIGO_PROYECTO"],
                    "DB":"BUPP",
                    "TABLES":[
                        {"SIIU_ETAPA_PROYECTO": None}
                    ]
                },
                {
                    "KEYS": ["CLASE_PROYECTO/IDENTIFICADOR"],
                    "DB":"BUPP",
                    "TABLES":[
                        {"SIIU_CLASE_PROYECTO": None}
                    ]
                },
                {
                    "KEYS": ["NIVEL_PROYECTO/IDENTIFICADOR"],
                    "DB":"BUPP",
                    "TABLES":[
                        {"SIIU_NIVEL_PROYECTO": None}
                    ]
                },
                {
                    "KEYS": ["SUBNIVEL_PROYECTO"],
                    "DB":"BUPP",
                    "TABLES":[
                        {"SIIU_SUBNIVEL_PROYECTO": None}
                    ]
                },
                {
                    "KEYS": ["TIPO_PROYECTO_MACRO/IDENTIFICADOR"],
                    "DB":"BUPP",
                    "TABLES":[
                        {"SIIU_TIPO_PROYECTO": None}
                    ]
                },
                {
                    "KEYS": ["SUBTIPO_PROYECTO/IDENTIFICADOR"],
                    "DB":"BUPP",
                    "TABLES":[
                        {"SIIU_SUBTIPO_PROYECTO": None}
                    ]
                }
            ]
        }
    ]
}



# RE_PROYECTO_RED está vacia, no se pueden obtener los proyectos por acá
graph_project = {"MAIN_TABLE": "EN_PROYECTO",
                 "CHECKPOINT": {"DB": "__CVLAC__", "KEYS": ["COD_RH", "COD_PROYECTO"]},
                 "SCHEMA_VERSION": 0.1,
                 "GRAPH": [{"EN_PROYECTO": [
                     # autor registrante
                     {"KEYS": ["COD_RH"],
                      "DB":"__CVLAC__",
                      "TABLES":[
                          {'EN_RECURSO_HUMANO': [
                              # municipio
                              {"KEYS": ["COD_RH_MUN_NACIM/COD_RH_MUNICIPIO", "COD_MUN_NACIM/COD_MUNICIPIO"],
                                  "DB":"__CVLAC__",
                                  "TABLES":[{'EN_MUNICIPIO': [
                                      # departamento
                                      {"KEYS": ["SGL_PAIS", "SGL_DEPARTAMENTO"],
                                       "DB":"__CVLAC__",
                                       "TABLES":[{'EN_DEPARTAMENTO': [
                                           # pais
                                           {"KEYS": ["SGL_PAIS"],
                                            "DB":"__CVLAC__",
                                            "TABLES":[{'EN_PAIS': None}]},

                                       ]}]},
                                  ]}]},
                              # level of studies
                              {"KEYS": ["COD_NIVEL_FORMACION"],
                                  "DB":"__CVLAC__",
                                  "TABLES":[{'EN_NIVEL_FORMACION': None}]},
                          ]},
                     ]},
                     # Re-Recurso humano otro
                     {"KEYS": ["COD_RH", "COD_PROYECTO"],
                      "DB":"__CVLAC__",
                      "TABLES":[{'RE_PROYECTO_REC_HUMANO_OTRO': [
                          # Autores otros
                          {"KEYS": ["COD_RH/COD_RH_CREA", "COD_RH_OTRO"],
                           "DB":"__CVLAC__",
                           "TABLES":[{'EN_RECURSO_HUMANO_OTRO': None}
                                     ]}
                      ]}
                     ]},

                     # institucion registrante
                     {"KEYS": ["COD_INST_AVALA/COD_INST"],
                      "DB":"__CVLAC__",
                      "TABLES":[{'EN_INSTITUCION': [
                          # pais
                          {"KEYS": ["SGL_PAIS"],
                           "DB":"__CVLAC__",
                           "TABLES":[{'EN_PAIS': None}]},

                      ]}]},
                     # Re-Institucion
                     {"KEYS": ["COD_RH", "COD_PROYECTO"],
                      "DB":"__CVLAC__",
                      "TABLES":[{'RE_PROYECTO_INSTITUCION':
                                 [
                                     # tipo de financiación (NO ESTA FUNCIONANDO ESTE!)
                                     {"KEYS": ["COD_TIPO_FINANCIACION"],
                                      "DB":"__CVLAC__",
                                      "TABLES":[{'EN_TIPO_FINANCIACION': None}
                                                ]},
                                     # institucion
                                     {"KEYS": ["COD_INST"],
                                      "DB":"__CVLAC__",
                                      "TABLES":[{'EN_INSTITUCION': [
                                          # pais
                                          {"KEYS": ["SGL_PAIS"],
                                           "DB":"__CVLAC__",
                                           "TABLES":[{'EN_PAIS': None}]},
                                      ]}
                                     ]},

                                     # instituciones
                                     {"KEYS": ["COD_RH", "COD_INST_OTRO/COD_INST"],
                                      "DB":"__CVLAC__",
                                      "TABLES":[
                                         # insticiones otras
                                         {'EN_INSTITUCION_OTRA': [
                                             # municipio
                                             {"KEYS": ["COD_RH_MUNICIPIO", "COD_MUNICIPIO"],
                                              "DB":"__CVLAC__",
                                              "TABLES":[{'EN_MUNICIPIO': [
                                                  # departamento
                                                  {"KEYS": ["SGL_PAIS", "SGL_DEPARTAMENTO"],
                                                   "DB":"__CVLAC__",
                                                   "TABLES":[{'EN_DEPARTAMENTO': [
                                                       # pais
                                                       {"KEYS": ["SGL_PAIS"],
                                                        "DB":"__CVLAC__",
                                                        "TABLES":[{'EN_PAIS': None}]},

                                                   ]}]},
                                              ]}]},

                                         ]},
                                     ]},

                                 ]}
                                ]},
                     # Re-proyecto producto
                     {"KEYS": ["COD_RH", "COD_PROYECTO"],
                      "DB":"__CVLAC__",
                      "TABLES":[{'RE_PROYECTO_PRODUCTO': [
                          # producto  (aca muere por que producto es tabla principal)
                          {"KEYS": ["COD_RH", "COD_PRODUCTO"],
                           "DB":"__CVLAC__",
                           "TABLES":[{'EN_PRODUCTO': None}
                                     ]}
                      ]}
                     ]},
                     # Re-proyecto evento
                     {"KEYS": ["COD_RH", "COD_PROYECTO"],
                      "DB":"__CVLAC__",
                      "TABLES":[{'RE_EVENTO_PROYECTO': [
                          # evento (aca muere por que evento es tabla principal)
                          {"KEYS": ["COD_RH", "COD_EVENTO"],
                           "DB":"__CVLAC__",
                           "TABLES":[{'EN_EVENTO': None}
                                     ]}
                      ]}
                     ]},
                     # Re-proyecto Comunidad
                     {"KEYS": ["COD_RH", "COD_PROYECTO"],
                      "DB":"__CVLAC__",
                      "TABLES":[{'RE_PROYECTO_COMUNIDAD': [
                                 # Comunidad
                                 {"KEYS": ["COD_RH", "COD_COMUNIDAD"],
                                  "DB":"__CVLAC__",
                                  "TABLES":[{'EN_COMUNIDAD': [
                                       # municipio
                                       {"KEYS": ["COD_RH_MUNICIPIO", "COD_MUNICIPIO"],
                                        "DB":"__CVLAC__",
                                        "TABLES":[{'EN_MUNICIPIO': [
                                            # departamento
                                            {"KEYS": ["SGL_PAIS", "SGL_DEPARTAMENTO"],
                                             "DB":"__CVLAC__",
                                             "TABLES":[{'EN_DEPARTAMENTO': [
                                                 # pais
                                                 {"KEYS": ["SGL_PAIS"],
                                                  "DB":"__CVLAC__",
                                                  "TABLES":[{'EN_PAIS': None}]},

                                             ]}]},
                                        ]}]},
                                       # Re-comunidad RED
                                       {"KEYS": ["COD_RH", "COD_COMUNIDAD"],
                                           "DB":"__CVLAC__",
                                           "TABLES":[{'RE_RED_COMUNIDAD': [
                                               # red (aca muere por que red es tabla principal)
                                               {"KEYS": ["COD_RH", "COD_RED"],
                                                "DB":"__CVLAC__",
                                                "TABLES":[{"EN_RED": None}]}
                                           ]}]},
                                       # Re-producto comunidad
                                       {"KEYS": ["COD_RH", "COD_COMUNIDAD"],
                                           "DB":"__CVLAC__",
                                           "TABLES":[{'RE_PRODUCTO_COMUNIDAD': [
                                               # producto (aca miere por que producto es tabla principal)
                                               {"KEYS": ["COD_RH", "COD_PRODUCTO"],
                                                "DB":"__CVLAC__",
                                                "TABLES":[{"EN_PRODUCTO": None}]}
                                           ]}]},

                                  ]}
                                 ]},
                                 ]}
                                ]},
                     # Grupo x Proyecto
                     {"KEYS": ["COD_RH", "COD_PROYECTO"],
                      "DB":"__GRUPLAC__",
                      "TABLES":[{'EN_PROYECTO_GR': [
                          # Grupo
                          {"KEYS": ["NRO_ID_GRUPO"],
                           "DB":"__GRUPLAC__",
                           "TABLES":[{"EN_GRUPO_PESQUISA": [
                               # re_institucion
                               {"KEYS": ["NRO_ID_GRUPO"],
                                "DB":"__GRUPLAC__",
                                "TABLES":[{'RE_GRUPO_INSTITUCION': [
                                    # institucion
                                    {"KEYS": ["COD_INST"],
                                     "DB":"__CVLAC__",
                                     "TABLES":[{'EN_INSTITUCION': [
                                         # pais
                                         {"KEYS": ["SGL_PAIS"],
                                          "DB":"__CVLAC__",
                                          "TABLES":[{'EN_PAIS': None}]},
                                     ]}
                                    ]}
                                ]}
                               ]},
                               # Area reconocimiento level 2 (tiene 3 niveles máximo) (es con COD_RH_AREA???)
                               {"KEYS": ['COD_RH_AREA/COD_RH', 'COD_AREA_CONHEC/COD_AREA_CONOCIMIENTO'],
                                   "DB":"__CVLAC__",
                                   "TABLES":[
                                   {"EN_AREA_CONOCIMIENTO": [
                                       # Area reconocimiento level 1
                                       {"KEYS": ['COD_RH_PADRE/COD_RH', "COD_AREA_PADRE/COD_AREA_CONOCIMIENTO"],
                                        "DB":"__CVLAC__",
                                        "TABLES":[{'EN_AREA_CONOCIMIENTO': [
                                            # Area reconocimiento level 0
                                            {"KEYS": ['COD_RH_PADRE/COD_RH', "COD_AREA_PADRE/COD_AREA_CONOCIMIENTO"],
                                             "DB":"__CVLAC__",
                                             "TABLES":[{'EN_AREA_CONOCIMIENTO': None}]},
                                        ]}
                                       ]},

                                   ]}
                               ]},
                           ]},
                          ]},
                      ]}
                     ]},

                 ]}
                 ]}



from .graph_fields_product import product_fields
from .graph_fields_network import network_fields
from .graph_fields_project import project_fields
from .graph_fields_event import event_fields
from .graph_fields_patent import patent_fields
from .graph_fields_endorsement import endorsement_fields
graph_fields = {}

# adding fields for every main entity
graph_fields["EN_PRODUCTO"] = product_fields
graph_fields["EN_RED"] = network_fields
graph_fields["EN_PROYECTO"] = project_fields
graph_fields["EN_EVENTO"] = event_fields
graph_fields["EN_PATENTE"] = patent_fields
graph_fields["EN_AVAL_INSTITUCION"] = endorsement_fields




# RE_PROYECTO_RED está vacia, no se pueden obtener los proyectos por acá
graph_network = {"MAIN_TABLE": "EN_RED",
                 "CHECKPOINT": {"DB": "__CVLAC__", "KEYS": ["COD_RH", "COD_RED"]},
                 "SCHEMA_VERSION": 0.1,
                 "GRAPH": [{"EN_RED": [
                     # autor registrante
                     {"KEYS": ["COD_RH"],
                      "DB":"__CVLAC__",
                      "TABLES":[
                          {'EN_RECURSO_HUMANO': [
                              # municipio
                              {"KEYS": ["COD_RH_MUN_NACIM/COD_RH_MUNICIPIO", "COD_MUN_NACIM/COD_MUNICIPIO"],
                                  "DB":"__CVLAC__",
                                  "TABLES":[{'EN_MUNICIPIO': [
                                      # departamento
                                      {"KEYS": ["SGL_PAIS", "SGL_DEPARTAMENTO"],
                                       "DB":"__CVLAC__",
                                       "TABLES":[{'EN_DEPARTAMENTO': [
                                           # pais
                                           {"KEYS": ["SGL_PAIS"],
                                            "DB":"__CVLAC__",
                                            "TABLES":[{'EN_PAIS': None}]},

                                       ]}]},
                                  ]}]},
                              # level of studies
                              {"KEYS": ["COD_NIVEL_FORMACION"],
                                  "DB":"__CVLAC__",
                                  "TABLES":[{'EN_NIVEL_FORMACION': None}]},
                          ]},
                     ]},

                     # institucion registrante
                     {"KEYS": ["COD_INST_AVALA/COD_INST"],
                      "DB":"__CVLAC__",
                      "TABLES":[{'EN_INSTITUCION': [
                          # pais
                          {"KEYS": ["SGL_PAIS"],
                           "DB":"__CVLAC__",
                           "TABLES":[{'EN_PAIS': None}]},

                      ]}]},
                     # Re-Institucion
                     {"KEYS": ["COD_RH", "COD_RED"],
                      "DB":"__CVLAC__",
                      "TABLES":[{'RE_INSTITUCION_RED': [
                          # instituciones
                          {"KEYS": ["COD_RH", "COD_INSTITUCION/COD_INST"],
                              "DB":"__CVLAC__",
                              "TABLES":[
                                  {'EN_INSTITUCION_OTRA': [
                                      # municipio
                                      {"KEYS": ["COD_RH_MUNICIPIO", "COD_MUNICIPIO"],
                                       "DB":"__CVLAC__",
                                       "TABLES":[{'EN_MUNICIPIO': [
                                           # departamento
                                           {"KEYS": ["SGL_PAIS", "SGL_DEPARTAMENTO"],
                                            "DB":"__CVLAC__",
                                            "TABLES":[{'EN_DEPARTAMENTO': [
                                                # pais
                                                {"KEYS": ["SGL_PAIS"],
                                                 "DB":"__CVLAC__",
                                                 "TABLES":[{'EN_PAIS': None}]},

                                            ]}]},
                                       ]}]},

                                  ]},
                          ]}
                      ]}
                     ]},
                     # Re-Autor otros
                     {"KEYS": ["COD_RH", "COD_RED"],
                      "DB":"__CVLAC__",
                      "TABLES":[{'RE_RH_O_RED': [
                          # Autores otros
                          {"KEYS": ["COD_RH/COD_RH_CREA", "COD_RH_OTRO"],
                           "DB":"__CVLAC__",
                           "TABLES":[{'EN_RECURSO_HUMANO_OTRO': None}
                                     ]}

                      ]}

                     ]},
                     # Re-Comunidad
                     {"KEYS": ["COD_RH", "COD_RED"],
                      "DB":"__CVLAC__",
                      "TABLES":[{'RE_RED_COMUNIDAD':
                                 # Comunidad
                                 [{"KEYS": ["COD_RH", "COD_COMUNIDAD"],
                                   "DB":"__CVLAC__",
                                   "TABLES":[{'EN_COMUNIDAD': [
                                       # municipio
                                       {"KEYS": ["COD_RH_MUNICIPIO", "COD_MUNICIPIO"],
                                        "DB":"__CVLAC__",
                                        "TABLES":[{'EN_MUNICIPIO': [
                                            # departamento
                                            {"KEYS": ["SGL_PAIS", "SGL_DEPARTAMENTO"],
                                             "DB":"__CVLAC__",
                                             "TABLES":[{'EN_DEPARTAMENTO': [
                                                 # pais
                                                 {"KEYS": ["SGL_PAIS"],
                                                  "DB":"__CVLAC__",
                                                  "TABLES":[{'EN_PAIS': None}]},

                                             ]}]},
                                        ]}]},
                                       # Re-proyecto comunidad
                                       {"KEYS": ["COD_RH", "COD_COMUNIDAD"],
                                           "DB":"__CVLAC__",
                                           "TABLES":[{'RE_PROYECTO_COMUNIDAD': [
                                               # proyecto
                                               {"KEYS": ["COD_RH", "COD_PROYECTO"],
                                                "DB":"__CVLAC__",
                                                "TABLES":[{"EN_PROYECTO": None}]}
                                           ]}]},
                                       # Re-producto comunidad
                                       {"KEYS": ["COD_RH", "COD_COMUNIDAD"],
                                           "DB":"__CVLAC__",
                                           "TABLES":[{'RE_PRODUCTO_COMUNIDAD': [
                                               # producto
                                               {"KEYS": ["COD_RH", "COD_PRODUCTO"],
                                                "DB":"__CVLAC__",
                                                "TABLES":[{"EN_PRODUCTO": None}]}
                                           ]}]},

                                   ]}
                                 ]},

                                 ]}
                                ]},

                     # Re-Grupo
                     {"KEYS": ["COD_RH", "COD_RED"],
                      "DB":"__GRUPLAC__",
                      "TABLES":[{'RE_GRUPO_RH_RED': [
                          # Grupo
                          {"KEYS": ["NRO_ID_GRUPO"],
                           "DB":"__GRUPLAC__",
                           "TABLES":[
                               {"EN_GRUPO_PESQUISA": [
                                   # re_institucion
                                   {"KEYS": ["NRO_ID_GRUPO"],
                                    "DB":"__GRUPLAC__",
                                    "TABLES":[{'RE_GRUPO_INSTITUCION': [
                                        # institucion
                                        {"KEYS": ["COD_INST"],
                                         "DB":"__CVLAC__",
                                         "TABLES":[{'EN_INSTITUCION': [
                                             # pais
                                             {"KEYS": ["SGL_PAIS"],
                                              "DB":"__CVLAC__",
                                              "TABLES":[{'EN_PAIS': None}]},
                                         ]}
                                        ]}
                                    ]}
                                   ]},
                                   # Area reconocimiento level 2 (tiene 3 niveles máximo) (es con COD_RH_AREA???)
                                   {"KEYS": ['COD_RH_AREA/COD_RH', 'COD_AREA_CONHEC/COD_AREA_CONOCIMIENTO'],
                                    "DB":"__CVLAC__",
                                    "TABLES":[
                                       {"EN_AREA_CONOCIMIENTO": [
                                           # Area reconocimiento level 1
                                           {"KEYS": ['COD_RH_PADRE/COD_RH', "COD_AREA_PADRE/COD_AREA_CONOCIMIENTO"],
                                            "DB":"__CVLAC__",
                                            "TABLES":[{'EN_AREA_CONOCIMIENTO': [
                                                # Area reconocimiento level 0
                                                {"KEYS": ['COD_RH_PADRE/COD_RH', "COD_AREA_PADRE/COD_AREA_CONOCIMIENTO"],
                                                 "DB":"__CVLAC__",
                                                 "TABLES":[{'EN_AREA_CONOCIMIENTO': None}]},
                                            ]}
                                           ]},

                                       ]}
                                   ]},
                               ]},
                          ]}
                      ]}

                     ]},

                 ]}
                 ]}



##
# event fields
##
event_fields = {}
event_fields["EN_RED"] = {"alias": "network"}
event_fields["EN_RED"]["fields"] = {
}

event_fields["EN_EVENTO"] = {"alias": "event"}
event_fields["EN_EVENTO"]["fields"] = {
}

event_fields["EN_INSTITUCION"] = {"alias": "institution"}
event_fields["EN_INSTITUCION"]["fields"] = {
}
event_fields["EN_INSTITUCION_OTRA"] = {"alias": "institution_other"}
event_fields["EN_INSTITUCION_OTRA"]["fields"] = {
}


event_fields["EN_RECURSO_HUMANO"] = {"alias": "author"}
event_fields["EN_RECURSO_HUMANO"]["fields"] = {
}

event_fields["EN_RECURSO_HUMANO_OTRO"] = {"alias": "author_others"}
event_fields["EN_RECURSO_HUMANO_OTRO"]["fields"] = {
}

event_fields["EN_COMUNIDAD"] = {"alias": "community", "sub_section": "details"}
event_fields["EN_COMUNIDAD"]["fields"] = {
}
event_fields["EN_PRODUCTO"] = {"alias": "product", "sub_section": "details"}
event_fields["EN_PRODUCTO"]["fields"] = {
}

event_fields["EN_MUNICIPIO"] = {"alias": "city"}
event_fields["EN_MUNICIPIO"]["fields"] = {
}
event_fields["EN_PROYECTO"] = {"alias": "project"}
event_fields["EN_PROYECTO"]["fields"] = {
}

event_fields["EN_GRUPO_PESQUISA"] = {"alias": "group"}
event_fields["EN_GRUPO_PESQUISA"]["fields"] = {
}

event_fields["EN_AREA_CONOCIMIENTO"] = {"alias": "knowledge_area"}
event_fields["EN_AREA_CONOCIMIENTO"]["fields"] = {
}

event_fields["EN_PALABRA_CLAVE"] = {
    "alias": "keywords", "sub_section": "details"}
event_fields["EN_PALABRA_CLAVE"]["fields"] = {
}

event_fields["EN_PAIS"] = {"alias": "country"}
event_fields["EN_PAIS"]["fields"] = {
}

event_fields["EN_SECTOR_APLICACION"] = {
    "alias": "application_sector", "sub_section": "details"}
event_fields["EN_SECTOR_APLICACION"]["fields"] = {
}


event_fields["EN_TIPO_EVENTO"] = {
    "alias": "type"}
event_fields["EN_TIPO_EVENTO"]["fields"] = {
}



# Scienti data model 2022
# SCHEMA version for modification on the relations, it is vertioned as well
from .graph_schema_product import graph_product
from .graph_schema_network import graph_network
from .graph_schema_project import graph_project
from .graph_schema_event import graph_event
from .graph_schema_patent import graph_patent
from .graph_schema_endorsement import graph_endorsement

graph_schema = {"SCIENTI_MODEL": 2022}
graph_schema["MODELS"] = {}


graph_schema["MODELS"]["network"] = graph_network
graph_schema["MODELS"]["product"] = graph_product
graph_schema["MODELS"]["project"] = graph_project
graph_schema["MODELS"]["event"] = graph_event
graph_schema["MODELS"]["patent"] = graph_patent
graph_schema["MODELS"]["endorsement"] = graph_endorsement




##
# project fields
##
project_fields = {}
project_fields["EN_PROYECTO"] = {"alias": "project"}
project_fields["EN_PROYECTO"]["fields"] = {
}

project_fields["EN_INSTITUCION"] = {"alias": "institution"}
project_fields["EN_INSTITUCION"]["fields"] = {
}
project_fields["EN_INSTITUCION_OTRA"] = {"alias": "institution_other"}
project_fields["EN_INSTITUCION_OTRA"]["fields"] = {
}

#project_fields["RE_PROYECTO_INSTITUCION"] = {"alias": "institutions"}
# project_fields["RE_PROYECTO_INSTITUCION"]["fields"] = {
# }

project_fields["EN_RECURSO_HUMANO"] = {"alias": "author"}
project_fields["EN_RECURSO_HUMANO"]["fields"] = {
}

project_fields["EN_RECURSO_HUMANO_OTRO"] = {"alias": "author_others"}
project_fields["EN_RECURSO_HUMANO_OTRO"]["fields"] = {
}

project_fields["EN_COMUNIDAD"] = {
    "alias": "community", "sub_section": "details"}
project_fields["EN_COMUNIDAD"]["fields"] = {
}
project_fields["EN_PRODUCTO"] = {"alias": "product", "sub_section": "details"}
project_fields["EN_PRODUCTO"]["fields"] = {
}

project_fields["EN_MUNICIPIO"] = {"alias": "city"}
project_fields["EN_MUNICIPIO"]["fields"] = {
}

project_fields["EN_DEPARTAMENTO"] = {"alias": "department"}
project_fields["EN_DEPARTAMENTO"]["fields"] = {
}

project_fields["EN_PAIS"] = {"alias": "country"}
project_fields["EN_PAIS"]["fields"] = {
}

project_fields["EN_PROYECTO"] = {"alias": "project"}
project_fields["EN_PROYECTO"]["fields"] = {
}

project_fields["EN_GRUPO_PESQUISA"] = {"alias": "group"}
project_fields["EN_GRUPO_PESQUISA"]["fields"] = {
}

project_fields["EN_AREA_CONOCIMIENTO"] = {"alias": "knowledge_area"}
project_fields["EN_AREA_CONOCIMIENTO"]["fields"] = {
}

project_fields["EN_NIVEL_FORMACION"] = {"alias": "studies_level"}
project_fields["EN_NIVEL_FORMACION"]["fields"] = {
}

project_fields["EN_TIPO_FINANCIACION"] = {
    "alias": "funding", "sub_section": "details"}
project_fields["EN_TIPO_FINANCIACION"]["fields"] = {
}

project_fields["EN_EVENTO"] = {"alias": "event", "sub_section": "details"}
project_fields["EN_EVENTO"]["fields"] = {
}


project_fields["EN_RED"] = {"alias": "network"}
project_fields["EN_RED"]["fields"] = {
}




##
# networks fields
##
network_fields = {}
network_fields["EN_RED"] = {"alias": "network"}
network_fields["EN_RED"]["fields"] = {
}

network_fields["EN_INSTITUCION"] = {"alias": "institution"}
network_fields["EN_INSTITUCION"]["fields"] = {
}
network_fields["EN_INSTITUCION_OTRA"] = {"alias": "institution_other"}
network_fields["EN_INSTITUCION_OTRA"]["fields"] = {
}

network_fields["EN_RECURSO_HUMANO"] = {"alias": "author"}
network_fields["EN_RECURSO_HUMANO"]["fields"] = {
}

network_fields["EN_RECURSO_HUMANO_OTRO"] = {"alias": "author_others"}
network_fields["EN_RECURSO_HUMANO_OTRO"]["fields"] = {
}

network_fields["EN_COMUNIDAD"] = {
    "alias": "community", "sub_section": "details"}
network_fields["EN_COMUNIDAD"]["fields"] = {
}
network_fields["EN_PRODUCTO"] = {"alias": "product"}
network_fields["EN_PRODUCTO"]["fields"] = {
}

network_fields["EN_MUNICIPIO"] = {"alias": "city"}
network_fields["EN_MUNICIPIO"]["fields"] = {
}

network_fields["EN_DEPARTAMENTO"] = {"alias": "department"}
network_fields["EN_DEPARTAMENTO"]["fields"] = {
}

network_fields["EN_PAIS"] = {"alias": "country"}
network_fields["EN_PAIS"]["fields"] = {
}

network_fields["EN_PROYECTO"] = {"alias": "project"}
network_fields["EN_PROYECTO"]["fields"] = {
}

network_fields["EN_GRUPO_PESQUISA"] = {"alias": "group"}
network_fields["EN_GRUPO_PESQUISA"]["fields"] = {
}

network_fields["EN_AREA_CONOCIMIENTO"] = {"alias": "knowledge_area"}
network_fields["EN_AREA_CONOCIMIENTO"]["fields"] = {
}

network_fields["EN_NIVEL_FORMACION"] = {"alias": "studies_level"}
network_fields["EN_NIVEL_FORMACION"]["fields"] = {
}



##
# patent fields
##
patent_fields = {}
patent_fields["EN_PATENTE"] = {"alias": "patent"}
patent_fields["EN_PATENTE"]["fields"] = {
}

patent_fields["EN_EVENTO"] = {"alias": "event"}
patent_fields["EN_EVENTO"]["fields"] = {
}

patent_fields["EN_INSTITUCION_OTRA"] = {"alias": "institution_other"}
patent_fields["EN_INSTITUCION_OTRA"]["fields"] = {
}

patent_fields["EN_INSTITUCION"] = {"alias": "institution"}
patent_fields["EN_INSTITUCION"]["fields"] = {
}
patent_fields["EN_INSTITUCION/PATENTADORA"] = {
    "alias": "patenting_institution"}
patent_fields["EN_INSTITUCION/PATENTADORA"]["fields"] = {
}
patent_fields["EN_INSTITUCION/EXPLOTADORA"] = {
    "alias": "operating_institution"}
patent_fields["EN_INSTITUCION/EXPLOTADORA"]["fields"] = {
}

patent_fields["EN_PROD_EMPRESA_ID"] = {"alias": "company"}
patent_fields["EN_PROD_EMPRESA_ID"]["fields"] = {
}


patent_fields["EN_RECURSO_HUMANO"] = {"alias": "author"}
patent_fields["EN_RECURSO_HUMANO"]["fields"] = {
}

patent_fields["EN_RECURSO_HUMANO_OTRO"] = {"alias": "author_others"}
patent_fields["EN_RECURSO_HUMANO_OTRO"]["fields"] = {
}

patent_fields["EN_COMUNIDAD"] = {
    "alias": "community",
    "sub_section": "details"}
patent_fields["EN_COMUNIDAD"]["fields"] = {
}
patent_fields["EN_PRODUCTO"] = {"alias": "product", "sub_section": "details"}
patent_fields["EN_PRODUCTO"]["fields"] = {
}

patent_fields["EN_PROD_TECNICA"] = {
    "alias": "technical",
    "sub_section": "details"}
patent_fields["EN_PROD_TECNICA"]["fields"] = {
}

patent_fields["EN_PROD_SOFTWARE"] = {
    "alias": "software",
    "sub_section": "details"}
patent_fields["EN_PROD_SOFTWARE"]["fields"] = {
}

patent_fields["EN_MUNICIPIO"] = {"alias": "city"}
patent_fields["EN_MUNICIPIO"]["fields"] = {
}
patent_fields["EN_PROYECTO"] = {"alias": "project"}
patent_fields["EN_PROYECTO"]["fields"] = {
}

patent_fields["EN_GRUPO_PESQUISA"] = {"alias": "group"}
patent_fields["EN_GRUPO_PESQUISA"]["fields"] = {
}

patent_fields["EN_AREA_CONOCIMIENTO"] = {"alias": "knowledge_area"}
patent_fields["EN_AREA_CONOCIMIENTO"]["fields"] = {
}

patent_fields["EN_PALABRA_CLAVE"] = {
    "alias": "keywords", "sub_section": "details"}
patent_fields["EN_PALABRA_CLAVE"]["fields"] = {
}

patent_fields["EN_PAIS"] = {"alias": "country"}
patent_fields["EN_PAIS"]["fields"] = {
}

patent_fields["EN_SECTOR_APLICACION"] = {
    "alias": "application_sector", "sub_section": "details"}
patent_fields["EN_SECTOR_APLICACION"]["fields"] = {
}

patent_fields["EN_TIPO_EVENTO"] = {
    "alias": "type"}
patent_fields["EN_TIPO_EVENTO"]["fields"] = {
}

patent_fields["EN_PROD_TECNOLOGICO"] = {
    "alias": "technological_product", "sub_section": "details"}
patent_fields["EN_PROD_TECNOLOGICO"]["fields"] = {
}

patent_fields["EN_SECRETO_INDUSTRIAL"] = {
    "alias": "industrial_secret", "sub_section": "details"}
patent_fields["EN_SECRETO_INDUSTRIAL"]["fields"] = {
}

patent_fields["EN_PROD_SOFTWARE"] = {
    "alias": "software", "sub_section": "details"}
patent_fields["EN_PROD_SOFTWARE"]["fields"] = {
}


patent_fields["EN_REGISTRO"] = {"alias": "register", "sub_section": "details"}
patent_fields["EN_REGISTRO"]["fields"] = {
}

patent_fields["EN_PROD_NORMA"] = {"alias": "rule", "sub_section": "details"}
patent_fields["EN_PROD_NORMA"]["fields"] = {
}

patent_fields["EN_PROD_VEGETAL"] = {
    "alias": "plant_product", "sub_section": "details"}
patent_fields["EN_PROD_VEGETAL"]["fields"] = {
}



##
# project fields
##
project_fields = {}
project_fields["SIIU_PROYECTO"] = {"alias": "project"}
project_fields["SIIU_PROYECTO"]["fields"] = {
}

project_fields["SIIU_COMPROMISO_POR_PROYECTO"] = {"alias": "project_commitment"}
project_fields["SIIU_COMPROMISO_POR_PROYECTO"]["fields"] = {
}

project_fields["SIIU_COMPROMISO"] = {"alias": "commitment"}
project_fields["SIIU_COMPROMISO"]["fields"] = {
}

project_fields["SIIU_ETAPA_PROYECTO"] = {"alias": "project_stage"}
project_fields["SIIU_ETAPA_PROYECTO"]["fields"] = {
}

project_fields["SIIU_ESTADO_PROYECTO"] = {"alias": "project_state"}
project_fields["SIIU_ESTADO_PROYECTO"]["fields"] = {
}

project_fields["SIIU_AVAL_APROBACION"] = {"alias": "aprob_aval"}
project_fields["SIIU_AVAL_APROBACION"]["fields"] = {
}

project_fields["SIIU_ACTUALIZACION_PROYECTO"] = {"alias": "project_update"}
project_fields["SIIU_ACTUALIZACION_PROYECTO"]["fields"] = {
}

project_fields["SIIU_EVALUACION_TECNICA"] = {"alias": "technical_eval"}
project_fields["SIIU_EVALUACION_TECNICA"]["fields"] = {
}

project_fields["SIIU_EVALUACION_CIENTIFICA"] = {"alias": "cientific_eval"}
project_fields["SIIU_EVALUACION_CIENTIFICA"]["fields"] = {
}

project_fields["SIIU_EVALUADOR_RECOMENDADO"] = {"alias": "recommended_evaluator"}
project_fields["SIIU_EVALUADOR_RECOMENDADO"]["fields"] = {
}

project_fields["SIIU_EVALUADOR"] = {"alias": "evaluator"}
project_fields["SIIU_EVALUADOR"]["fields"] = {
}

project_fields["SIIU_PARTICIPANTE_PROYECTO"] = {"alias": "project_participant"}
project_fields["SIIU_PARTICIPANTE_PROYECTO"]["fields"] = {
}

project_fields["SIIU_ROL_PARTICIPANTE_PROYECTO"] = {"alias": "project_participant_role"}
project_fields["SIIU_ROL_PARTICIPANTE_PROYECTO"]["fields"] = {
}

project_fields["SIIU_GRUPO"] = {"alias": "group"}
project_fields["SIIU_GRUPO"]["fields"] = {
}

project_fields["SIIU_APORTANTE_PROYECTO"] = {"alias": "project_contributor"}
project_fields["SIIU_APORTANTE_PROYECTO"]["fields"] = {
}

project_fields["SIIU_SEGUIMIENTO_APORTANTE"] = {"alias": "contributor_follow_up"}
project_fields["SIIU_SEGUIMIENTO_APORTANTE"]["fields"] = {
}

project_fields["SIIU_MODIFICACION_PRESUPUESTAL"] = {"alias": "budget_modification"}
project_fields["SIIU_MODIFICACION_PRESUPUESTAL"]["fields"] = {
}

project_fields["SIIU_CLASE_PROYECTO"] = {"alias": "project_class"}
project_fields["SIIU_CLASE_PROYECTO"]["fields"] = {
}

project_fields["SIIU_NIVEL_PROYECTO"] = {"alias": "project_level"}
project_fields["SIIU_NIVEL_PROYECTO"]["fields"] = {
}

project_fields["SIIU_SUBNIVEL_PROYECTO"] = {"alias": "project_sublevel"}
project_fields["SIIU_SUBNIVEL_PROYECTO"]["fields"] = {
}

project_fields["SIIU_TIPO_PROYECTO"] = {"alias": "project_type"}
project_fields["SIIU_TIPO_PROYECTO"]["fields"] = {
}

project_fields["SIIU_SUBTIPO_PROYECTO"] = {"alias": "project_subtype"}
project_fields["SIIU_SUBTIPO_PROYECTO"]["fields"] = {
}

project_fields["SIIU_TEXTO_DESCRIPTIVO"] = {"alias": "descriptive_text"}
project_fields["SIIU_TEXTO_DESCRIPTIVO"]["fields"] = {
}

project_fields["SIIU_TEXTO_SOLICITADO"] = {"alias": "requested_text"}
project_fields["SIIU_TEXTO_SOLICITADO"]["fields"] = {
}

project_fields["SIIU_DOCUMENTO_PROYECTO"] = {"alias": "project_doc"}
project_fields["SIIU_DOCUMENTO_PROYECTO"]["fields"] = {
}

project_fields["SIIU_DOCUMENTO_SOPORTE"] = {"alias": "support_doc"}
project_fields["SIIU_DOCUMENTO_SOPORTE"]["fields"] = {
}

project_fields["SMAP_PROYECTO_IFORMAL"] = {"alias": "iformal"}
project_fields["SMAP_PROYECTO_IFORMAL"]["fields"] = {
}

project_fields["SIIU_DATOS_SUBPROYECTOS"] = {"alias": "subproject_data"}
project_fields["SIIU_DATOS_SUBPROYECTOS"]["fields"] = {
}

project_fields["SMAP_SOLICITUD_ADM"] = {"alias": "adm_request"}
project_fields["SMAP_SOLICITUD_ADM"]["fields"] = {
}

project_fields["SIIU_COMPONENTE_PROYECTO"] = {"alias": "project_component"}
project_fields["SIIU_COMPONENTE_PROYECTO"]["fields"] = {
}

project_fields["SIIU_DETALLE_MODIF_PPTAL"] = {"alias": "budget_modification_details"}
project_fields["SIIU_DETALLE_MODIF_PPTAL"]["fields"] = {
}

project_fields["SIIU_SEGUIMIENTO_PRESUPUESTO"] = {"alias": "budget_follow_up"}
project_fields["SIIU_SEGUIMIENTO_PRESUPUESTO"]["fields"] = {
}

project_fields["SIIU_SEGUIMIENTO_PPTO_INICIAL"] = {"alias": "initial_budget_follow_up"}
project_fields["SIIU_SEGUIMIENTO_PPTO_INICIAL"]["fields"] = {
}

project_fields["SMAP_SOL_ADICION_PRESUPUESTAL"] = {"alias": "budget_addition_request"}
project_fields["SMAP_SOL_ADICION_PRESUPUESTAL"]["fields"] = {
}

project_fields["SMAP_SOLICITUD_CAMBIO_RUBRO"] = {"alias": "item_change_request"}
project_fields["SMAP_SOLICITUD_CAMBIO_RUBRO"]["fields"] = {
}

project_fields["SIIU_ETAPA_PROCESO_SELECCION"] = {"alias": "selection_process_stage"}
project_fields["SIIU_ETAPA_PROCESO_SELECCION"]["fields"] = {
}

project_fields["SIIU_FECHA_PROCESO_SELECCION"] = {"alias": "selection_process_date"}
project_fields["SIIU_FECHA_PROCESO_SELECCION"]["fields"] = {
}

project_fields["SIIU_PERSONA_NATURAL"] = {"alias": "natural_person"}
project_fields["SIIU_PERSONA_NATURAL"]["fields"] = {
}

project_fields["SIIU_PERSONA_JURIDICA"] = {"alias": "legal_entity"}
project_fields["SIIU_PERSONA_JURIDICA"]["fields"] = {
}



def siiu_filter(table_name, data_row):
    """
    Funtion that replaces na values by None,
    otherwise the created JSON gets corrupted for having
    null values it does not recognize,
    for this case the na values are the ones recognized
    by pandas as such.
    
    Parameters:
    table_name:str
        name of the table we are currently filtering
    data_row:pandas.Series
        one arrow of the current table
    Returns:
        dictionary with the clean data.
    NOTE: this is called by the funciton ukupacha.Utils.parse_table
    """
    return data_row.astype(object).where(data_row.notna(), None)



graph_patent = {"MAIN_TABLE": "EN_PATENTE",
                "CHECKPOINT": {"DB": "__CVLAC__", "KEYS": ["COD_RH", "COD_PATENTE"]},
                "SCHEMA_VERSION": 0.1,
                "GRAPH": [{"EN_PATENTE": [
                    # autor registrante
                    {"KEYS": ["COD_RH"],
                     "DB":"__CVLAC__",
                     "TABLES":[{'EN_RECURSO_HUMANO': [
                         # municipio
                         {"KEYS": ["COD_RH_MUN_NACIM/COD_RH_MUNICIPIO", "COD_MUN_NACIM/COD_MUNICIPIO"],
                          "DB":"__CVLAC__",
                          "TABLES":[{'EN_MUNICIPIO': [
                              # departamento
                              {"KEYS": ["SGL_PAIS", "SGL_DEPARTAMENTO"],
                               "DB":"__CVLAC__",
                               "TABLES":[{'EN_DEPARTAMENTO': [
                                   # pais
                                   {"KEYS": ["SGL_PAIS"],
                                    "DB":"__CVLAC__",
                                    "TABLES":[{'EN_PAIS': None}]},

                               ]}]},
                          ]}]},
                         # level of studies
                         {"KEYS": ["COD_NIVEL_FORMACION"],
                             "DB":"__CVLAC__",
                          "TABLES":[{'EN_NIVEL_FORMACION': None}]},
                     ]},
                    ]},

                    # institucion patentadora(Esta no va a COD_INS para patente)
                    # no tiene sentido el COD, voy a usar ID
                    {"KEYS": ["ID_INST_PATENTADORA/ID_INSTITUCION"],
                     "DB":"__CVLAC__",
                     "TABLES":[{'EN_INSTITUCION/PATENTADORA': [  # EN_INSTITUCION/patenting_institution
                         # pais
                         {"KEYS": ["SGL_PAIS"],
                          "DB":"__CVLAC__",
                          "TABLES":[{'EN_PAIS': None}]},

                     ]}]},
                    # institucion explotadora(Esta no va a COD_INS para patente)
                    # no tiene sentido el COD voy a usar ID
                    {"KEYS": ["COD_INST_CONTR_EXPL/COD_INST"],
                     "DB":"__CVLAC__",
                     "TABLES":[{'EN_INSTITUCION/EXPLOTADORA': [
                         # pais
                         {"KEYS": ["SGL_PAIS"],
                          "DB":"__CVLAC__",
                          "TABLES":[{'EN_PAIS': None}]},

                     ]}]},
                    # Re-Institucion otra
                    {"KEYS": ["COD_RH", "COD_INST_OTRO/COD_INST"],
                     "DB":"__CVLAC__",
                     "TABLES":[{'EN_INSTITUCION_OTRA': None}

                               ]},
                    # prod_tecnica
                    {"KEYS": ["COD_RH", "COD_PRODUCTO"],
                     "DB":"__CVLAC__",
                     "TABLES":[{'EN_PROD_TECNICA': [
                         {"KEYS": ["COD_RH", "COD_PRODUCTO"],
                          "DB":"__CVLAC__",
                          "TABLES":[{"EN_PRODUCTO": None},
                                    {"EN_PROD_EMPRESA_ID": None},
                                    {"EN_PROD_SOFTWARE": None},
                                    {"EN_PROD_VEGETAL": None},
                                    {"EN_PROD_TECNOLOGICO": None},
                                    {"EN_SECRETO_INDUSTRIAL": None},
                                    {"EN_REGISTRO": None},
                                    # Producto Norma
                                    {'EN_PROD_NORMA': [
                                        # Editorial
                                        {"KEYS": ["COD_EDITORIAL"],
                                         "DB":"__CVLAC__",
                                         "TABLES":[{'EN_EDITORIAL': None}]},
                                        # Editorial others
                                        {"KEYS": ["COD_RH", "COD_EDITORIAL_OTRO/COD_EDITORIAL"],
                                         "DB":"__CVLAC__",
                                         "TABLES":[{'EN_EDITORIAL_OTRO': None}]},

                                    ]},

                                    ]}
                     ]}

                    ]},

                ]}
                ]}



def scienti_filter(table_name, data_row):
    """
    Funtion that allows to filter unwanted data from the json.
    for this case:
        * fields with "FILTRO"
        * values with the string "nan"
        * passwords
    anything can be set here to remove unwanted data.
    Parameters:
    table_name:str
        name of the table we are currently filtering
    data_row:pandas.Series
        one arrow of the current table
    Returns:
        dictionary with the clean data.

    NOTE: this is called by the funciton ukupacha.Utils.parse_table
    """
    #data_row.dropna(inplace=True)
    data = {}
    for key, value in data_row.items():
        #if "FILTRO" in key:
        #    continue
        # if value == "nan":
        #    continue
        if key == "TXT_CONTRASENA":
            continue
        data[key] = value
    return data
